#define _GNU_SOURCE
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>
#include <string.h>
#include <errno.h>
#include <sys/syscall.h>

struct ViceIoctl {
        char    *in;
        char    *out;
        short   in_size;
        short   out_size;
};

#define AFSCALL_PIOCTL	0x14
#define PGetFID		0x22		/* get file ID */

#define afs_call(function, ...)	(syscall(SYS_afs_syscall, (function), __VA_ARGS__))

static inline long pioctl(const char *path,
			  int cmd,
			  struct ViceIoctl *arg,
			  int follow)
{
	return afs_call(AFSCALL_PIOCTL, path, cmd, arg, follow);
}

int main(int argc, char *argv[])
{
	struct ViceIoctl vioc;
	char buffer[256];
	long ret;
	int loop;

	if (argc != 2) {
		fprintf(stderr, "Format: %s <file>\n", argv[0]);
		return 2;
	}

	/* poison the reply buffer before letting AFS see it */
	memset(buffer, 0x5a, sizeof(buffer));

	vioc.in = NULL;
	vioc.in_size = 0;
	vioc.out = buffer;
	vioc.out_size = sizeof(buffer);

	ret = pioctl(argv[1], PGetFID, &vioc, 1);
	if (ret < 0) {
		perror(argv[1]);
		return 1;
	}

	printf("success: %hd\n", vioc.out_size);
	printf("reply:");
	for (loop = 0; loop < vioc.out_size; loop++) {
		printf("%02x", (uint8_t) buffer[loop]);
		if (loop % 4 == 3)
			printf(" ");
	}
	printf("\n");
	return 0;
}		
